import React, { useState } from "react";
import { useNavigate } from "react-router-dom";
import MailIcon from "d:/360ExtremeBrowserDownload/Mail.svg";
import PasswordEyeIcon from "d:/360ExtremeBrowserDownload/Password eye.svg";
import './styles.css'; // Import the CSS file

const LoginPage = () => {
  const [showPassword, setShowPassword] = useState(false);
  const [email, setEmail] = useState("");
  const [emailError, setEmailError] = useState("");
  const navigate = useNavigate();

  const togglePasswordVisibility = () => {
    setShowPassword(!showPassword);
  };

  const validateEmail = (email) => {
    const emailRegex = /^[^\s@]+@[^\s@]+\.[^\s@]+$/;
    return emailRegex.test(email);
  };

  const handleCheckStatusClick = () => {
    if (!validateEmail(email)) {
      setEmailError("Please enter a valid email address.");
      return;
    }

    // Validate the URL before navigating
    const allowedUrls = ["/status"];
    const targetUrl = "/status";

    if (allowedUrls.includes(targetUrl)) {
      navigate(targetUrl);
    } else {
      console.error("Invalid URL redirection attempt");
    }
  };

  return (
    <div className="flex items-center justify-center min-h-screen bg-blue-100">
      <div className="absolute top-[66px] left-[139px]">
        <h1 className="font-montserrat font-bold text-[48.31px] leading-[100%]">
          OMPOI - Seller
        </h1>
      </div>
      <div className="absolute top-[194px] left-[134px] bg-white p-8 rounded-[32.6px] shadow-lg w-[1460.608px] h-[729px] flex">
        {/* Left Side - Illustration */}
        <div className="w-1/2 flex items-center justify-center p-5">
          <img
            src="/Frame 201.svg"
            alt="Illustration"
            className="w-full h-auto"
          />
        </div>

        {/* Right Side - Login Form */}
        <div className="w-1/2 p-10 flex flex-col justify-center">
          <h2 className="text-2xl font-semibold mb-6">Check Status</h2>
          
          <div className="mb-4">
            <label className="block text-gray-600 mb-1">Email ID</label>
            <div className="relative">
              <input
                type="email"
                placeholder="Enter Email ID"
                value={email}
                onChange={(e) => setEmail(e.target.value)}
                className="w-full pl-4 pr-10 py-2 border rounded-lg focus:outline-none focus:ring-2 focus:ring-blue-400"
              />
              <img
                src={MailIcon}
                alt="Mail Icon"
                className="absolute right-3 top-3 w-5 h-5"
              />
            </div>
            {emailError && <p className="text-red-500 text-sm mt-1">{emailError}</p>}
          </div>

          <div className="mb-4">
            <label className="block text-gray-600 mb-1">Password</label>
            <div className="relative">
              <input
                type={showPassword ? "text" : "password"}
                placeholder="Enter your password"
                className="w-full px-4 py-2 border rounded-lg focus:outline-none focus:ring-2 focus:ring-blue-400"
              />
              <img
                src={PasswordEyeIcon}
                alt="Password Eye Icon"
                className="absolute right-3 top-3 w-5 h-5 cursor-pointer"
                onClick={togglePasswordVisibility}
              />
            </div>
          </div>

          <div className="flex justify-between text-sm mb-6">
            <a href="#" className="text-gray-500">Forgot Password?</a>
            <a href="#" className="text-orange-500 font-medium">Create an Account</a>
          </div>

          {/* Updated button to navigate to Status Page with animation */}
          <button
            onClick={handleCheckStatusClick}
            className="w-full bg-transparent border-2 border-orange-500 text-orange-500 py-2 rounded-full hover:bg-orange-500 hover:text-white transition animated-button"
          >
            Check Status
          </button>
        </div>
      </div>
    </div>
  );
};

export default LoginPage;
